@@ -1,6 +1,5 @@
 /* bfd initialization stuff
-   Copyright 1990, 1991, 1992, 1993, 1994, 1995, 2003, 2005, 2007
-   Free Software Foundation, Inc.
+   Copyright (C) 1990-2023 Free Software Foundation, Inc.
    Written by Steve Chamberlain of Cygnus Support.
 
    This file is part of BFD, the Binary File Descriptor library.
@@ -34,22 +33,3 @@ SUBSECTION
 	These are the functions that handle initializing a BFD.
 */
 
-/*
-FUNCTION
-	bfd_init
-
-SYNOPSIS
-	void bfd_init (void);
-
-DESCRIPTION
-	This routine must be called before any other BFD function to
-	initialize magical internal data structures.
-*/
-
-/* Actually, there is currently nothing for this function to do.
-   However, someday it may be needed, so keep it around.  */
-
-void
-bfd_init (void)
-{
-}
