@@ -1,6 +1,5 @@
 /* BFD ECOFF object file private structure.
-   Copyright 1993, 1994, 1995, 1996, 1999, 2001, 2002, 2003, 2004,
-   2005, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1993-2023 Free Software Foundation, Inc.
    Written by Ian Lance Taylor, Cygnus Support.
 
    This file is part of BFD, the Binary File Descriptor library.
@@ -48,7 +47,7 @@ struct ecoff_backend_data
   /* TRUE if the .rdata section is part of the text segment, as on the
      Alpha.  FALSE if .rdata is part of the data segment, as on the
      MIPS.  */
-  bfd_boolean rdata_in_text;
+  bool rdata_in_text;
   /* Bitsize of constructor entries.  */
   unsigned int constructor_bitsize;
   /* Reloc to use for constructor entries.  */
@@ -66,14 +65,26 @@ struct ecoff_backend_data
   void (*adjust_reloc_out)
     (bfd *, const arelent *, struct internal_reloc *);
   /* Relocate section contents while linking.  */
-  bfd_boolean (*relocate_section)
+  bool (*relocate_section)
     (bfd *, struct bfd_link_info *, bfd *, asection *, bfd_byte *, void *);
   /* Do final adjustments to filehdr and aouthdr.  */
-  bfd_boolean (*adjust_headers)
+  bool (*adjust_headers)
     (bfd *, struct internal_filehdr *, struct internal_aouthdr *);
   /* Read an element from an archive at a given file position.  This
      is needed because OSF/1 3.2 uses a weird archive format.  */
-  bfd *(*get_elt_at_filepos) (bfd *, file_ptr);
+  bfd *(*get_elt_at_filepos) (bfd *, file_ptr, struct bfd_link_info *);
+};
+
+/* ECOFF targets don't support COFF long section names, so this
+  macro is provided to use as an initialiser for the related
+  members of the embedded bfd_coff_backend_data struct.  */
+#define ECOFF_NO_LONG_SECTION_NAMES (false), _bfd_ecoff_no_long_sections
+
+struct mips_hi
+{
+  struct mips_hi *next;
+  bfd_byte *addr;
+  bfd_vma addend;
 };
 
 /* This is the target specific information kept for ECOFF files.  */
@@ -113,9 +124,6 @@ typedef struct ecoff_tdata
   /* The ECOFF symbolic debugging information.  */
   struct ecoff_debug_info debug_info;
 
-  /* The unswapped ECOFF symbolic information.  */
-  void * raw_syments;
-
   /* The canonical BFD symbols.  */
   struct ecoff_symbol_struct *canonical_symbols;
 
@@ -128,11 +136,11 @@ typedef struct ecoff_tdata
   asection **symndx_to_section;
 
   /* TRUE if this BFD was written by the backend linker.  */
-  bfd_boolean linker;
+  bool linker;
 
   /* TRUE if a warning that multiple global pointer values are
      needed in the output binary was issued already.  */
-  bfd_boolean issued_multiple_gp_warning;
+  bool issued_multiple_gp_warning;
 
   /* Used by find_nearest_line entry point.  The structure could be
      included directly in this one, but there's no point to wasting
@@ -142,8 +150,10 @@ typedef struct ecoff_tdata
   /* Whether the .rdata section is in the text segment for this
      particular ECOFF file.  This is not valid until
      ecoff_compute_section_file_positions is called.  */
-  bfd_boolean rdata_in_text;
+  bool rdata_in_text;
 
+  /* Used by coff-mips.c to track REFHI relocs for pairing with REFLO.  */
+  struct mips_hi *mips_refhi_list;
 } ecoff_data_type;
 
 /* Each canonical asymbol really looks like this.  */
@@ -157,7 +167,7 @@ typedef struct ecoff_symbol_struct
   FDR *fdr;
 
   /* TRUE if this is a local symbol rather than an external one.  */
-  bfd_boolean local;
+  bool local;
 
   /* A pointer to the unswapped hidden information for this symbol.
      This is either a struct sym_ext or a struct ext_ext, depending on
@@ -220,27 +230,27 @@ struct ecoff_link_hash_table
 };
 
 /* Make an ECOFF object.  */
-extern bfd_boolean _bfd_ecoff_mkobject (bfd *);
+extern bool _bfd_ecoff_mkobject (bfd *);
 
 /* Read in the ECOFF symbolic debugging information.  */
-extern bfd_boolean _bfd_ecoff_slurp_symbolic_info
+extern bool _bfd_ecoff_slurp_symbolic_info
   (bfd *, asection *, struct ecoff_debug_info *);
 
 /* Generic ECOFF BFD backend vectors.  */
 
-extern bfd_boolean _bfd_ecoff_write_object_contents (bfd *);
-extern const bfd_target *_bfd_ecoff_archive_p (bfd *);
+extern bool _bfd_ecoff_write_object_contents (bfd *);
 
-#define	_bfd_ecoff_close_and_cleanup _bfd_generic_close_and_cleanup
-#define _bfd_ecoff_bfd_free_cached_info _bfd_generic_bfd_free_cached_info
-extern bfd_boolean _bfd_ecoff_new_section_hook
+#define _bfd_ecoff_close_and_cleanup _bfd_generic_close_and_cleanup
+extern bool _bfd_ecoff_bfd_free_cached_info (bfd *);
+extern bool _bfd_ecoff_new_section_hook
   (bfd *, asection *);
-extern bfd_boolean _bfd_ecoff_get_section_contents
+extern bool _bfd_ecoff_get_section_contents
   (bfd *, asection *, void * location, file_ptr, bfd_size_type);
 
 #define _bfd_ecoff_bfd_link_split_section _bfd_generic_link_split_section
+#define _bfd_ecoff_bfd_link_check_relocs  _bfd_generic_link_check_relocs
 
-extern bfd_boolean _bfd_ecoff_bfd_copy_private_bfd_data
+extern bool _bfd_ecoff_bfd_copy_private_bfd_data
   (bfd *, bfd *);
 #define _bfd_ecoff_bfd_copy_private_section_data \
   _bfd_generic_bfd_copy_private_section_data
@@ -258,21 +268,21 @@ extern bfd_boolean _bfd_ecoff_bfd_copy_private_bfd_data
   _bfd_generic_bfd_merge_private_bfd_data
 
 #define _bfd_ecoff_bfd_set_private_flags _bfd_generic_bfd_set_private_flags
-extern bfd_boolean _bfd_ecoff_slurp_armap (bfd *);
+extern bool _bfd_ecoff_slurp_armap (bfd *);
 #define _bfd_ecoff_slurp_extended_name_table _bfd_slurp_extended_name_table
 #define _bfd_ecoff_construct_extended_name_table \
   _bfd_archive_bsd_construct_extended_name_table
 #define _bfd_ecoff_truncate_arname bfd_dont_truncate_arname
-extern bfd_boolean _bfd_ecoff_write_armap
+extern bool _bfd_ecoff_write_armap
   (bfd *, unsigned int, struct orl *, unsigned int, int);
 #define _bfd_ecoff_read_ar_hdr _bfd_generic_read_ar_hdr
+#define _bfd_ecoff_write_ar_hdr _bfd_generic_write_ar_hdr
 #define _bfd_ecoff_openr_next_archived_file \
   bfd_generic_openr_next_archived_file
 #define _bfd_ecoff_get_elt_at_index _bfd_generic_get_elt_at_index
 #define _bfd_ecoff_generic_stat_arch_elt bfd_generic_stat_arch_elt
-#define _bfd_ecoff_update_armap_timestamp bfd_true
-#define _bfd_ecoff_bfd_is_target_special_symbol  \
-  ((bfd_boolean (*) (bfd *, asymbol *)) bfd_false)
+#define _bfd_ecoff_update_armap_timestamp _bfd_bool_bfd_true
+#define _bfd_ecoff_bfd_is_target_special_symbol _bfd_bool_bfd_asymbol_false
 
 extern long _bfd_ecoff_get_symtab_upper_bound (bfd *);
 extern long _bfd_ecoff_canonicalize_symtab (bfd *, asymbol **);
@@ -281,12 +291,17 @@ extern void _bfd_ecoff_print_symbol
   (bfd *, void *, asymbol *, bfd_print_symbol_type);
 extern void _bfd_ecoff_get_symbol_info
   (bfd *, asymbol *, symbol_info *);
-extern bfd_boolean _bfd_ecoff_bfd_is_local_label_name
+#define _bfd_ecoff_get_symbol_version_string \
+  _bfd_nosymbols_get_symbol_version_string
+extern bool _bfd_ecoff_bfd_is_local_label_name
   (bfd *, const char *);
 #define _bfd_ecoff_get_lineno _bfd_nosymbols_get_lineno
-extern bfd_boolean _bfd_ecoff_find_nearest_line
-  (bfd *, asection *, asymbol **, bfd_vma, const char **, const char **,
-   unsigned int *);
+extern bool _bfd_ecoff_find_nearest_line
+  (bfd *, asymbol **, asection *, bfd_vma,
+   const char **, const char **, unsigned int *, unsigned int *);
+#define _bfd_ecoff_find_nearest_line_with_alt \
+  _bfd_nosymbols_find_nearest_line_with_alt
+#define _bfd_ecoff_find_line _bfd_nosymbols_find_line
 #define _bfd_ecoff_bfd_make_debug_symbol _bfd_nosymbols_bfd_make_debug_symbol
 #define _bfd_ecoff_read_minisymbols _bfd_generic_read_minisymbols
 #define _bfd_ecoff_minisymbol_to_symbol _bfd_generic_minisymbol_to_symbol
@@ -294,12 +309,12 @@ extern bfd_boolean _bfd_ecoff_find_nearest_line
 
 #define _bfd_ecoff_get_reloc_upper_bound coff_get_reloc_upper_bound
 extern long _bfd_ecoff_canonicalize_reloc
-  (bfd *, asection *, arelent **, asymbol **symbols);
+  (bfd *, asection *, arelent **, asymbol **);
 /* ecoff_bfd_reloc_type_lookup defined by backend. */
 
-extern bfd_boolean _bfd_ecoff_set_arch_mach
+extern bool _bfd_ecoff_set_arch_mach
   (bfd *, enum bfd_architecture, unsigned long);
-extern bfd_boolean _bfd_ecoff_set_section_contents
+extern bool _bfd_ecoff_set_section_contents
   (bfd *, asection *, const void * location, file_ptr, bfd_size_type);
 
 extern int _bfd_ecoff_sizeof_headers (bfd *, struct bfd_link_info *);
@@ -307,25 +322,26 @@ extern int _bfd_ecoff_sizeof_headers (bfd *, struct bfd_link_info *);
 /* ecoff_bfd_relax_section defined by backend.  */
 extern struct bfd_link_hash_table *_bfd_ecoff_bfd_link_hash_table_create
   (bfd *);
-#define _bfd_ecoff_bfd_link_hash_table_free _bfd_generic_link_hash_table_free
-extern bfd_boolean _bfd_ecoff_bfd_link_add_symbols
+extern bool _bfd_ecoff_bfd_link_add_symbols
   (bfd *, struct bfd_link_info *);
 #define _bfd_ecoff_bfd_link_just_syms _bfd_generic_link_just_syms
 #define _bfd_ecoff_bfd_copy_link_hash_symbol_type \
   _bfd_generic_copy_link_hash_symbol_type
-extern bfd_boolean _bfd_ecoff_bfd_final_link
+extern bool _bfd_ecoff_bfd_final_link
   (bfd *, struct bfd_link_info *);
 
 /* Hook functions for the generic COFF section reading code.  */
 
 extern void * _bfd_ecoff_mkobject_hook (bfd *, void *, void *);
-#define _bfd_ecoff_set_alignment_hook \
-  ((void (*) (bfd *, asection *, void *)) bfd_void)
-extern bfd_boolean _bfd_ecoff_set_arch_mach_hook
+extern void _bfd_ecoff_set_alignment_hook
+  (bfd *, asection *, void *);
+extern bool _bfd_ecoff_set_arch_mach_hook
   (bfd *, void *);
-extern bfd_boolean _bfd_ecoff_styp_to_sec_flags
+extern bool _bfd_ecoff_no_long_sections
+  (bfd *abfd, int enable);
+extern bool _bfd_ecoff_styp_to_sec_flags
   (bfd *, void *, const char *, asection *, flagword *);
-extern bfd_boolean _bfd_ecoff_slurp_symbol_table (bfd *);
+extern bool _bfd_ecoff_slurp_symbol_table (bfd *);
 
 /* ECOFF auxiliary information swapping routines.  These are the same
    for all ECOFF targets, so they are defined in ecofflink.c.  */
