@@ -1,5 +1,5 @@
 /* tc-iq2000.h -- Header file for tc-iq2000.c.
-   Copyright (C) 2003-2018 Free Software Foundation, Inc.
+   Copyright (C) 2003-2023 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -45,8 +45,6 @@
 
 #define tc_frob_file() iq2000_frob_file ()
 
-#define obj_fix_adjustable(fixP) iq2000_fix_adjustable (fixP)
-
 /* After creating a fixup for an instruction operand, we need to check
    for HI16 relocs and queue them up for later sorting.  */
 #define md_cgen_record_fixup_exp  iq2000_cgen_record_fixup_exp
@@ -59,7 +57,6 @@
 
 #define tc_gen_reloc gas_cgen_tc_gen_reloc
 
-extern void         iq2000_frob_file         (void);
-extern bfd_boolean  iq2000_fix_adjustable    (struct fix *);
-extern int          iq2000_force_relocation  (struct fix *);
-extern long         md_pcrel_from_section    (struct fix *, segT);
+extern void iq2000_frob_file (void);
+extern bool iq2000_fix_adjustable (struct fix *);
+extern int iq2000_force_relocation (struct fix *);
