@@ -1,6 +1,6 @@
 /* corefile.c
 
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This file is part of GNU Binutils.
 
@@ -45,7 +45,7 @@ unsigned int symbol_map_count;
 
 static void read_function_mappings (const char *);
 static int core_sym_class (asymbol *);
-static bfd_boolean get_src_info
+static bool get_src_info
   (bfd_vma, const char **, const char **, int *);
 
 extern void i386_find_call  (Sym *, bfd_vma, bfd_vma);
@@ -332,7 +332,7 @@ find_call (Sym *parent, bfd_vma p_lowpc, bfd_vma p_highpc)
 	       whoami, bfd_printable_name(core_bfd));
 
       /* Don't give the error more than once.  */
-      ignore_direct_calls = FALSE;
+      ignore_direct_calls = false;
     }
 }
 
@@ -453,8 +453,9 @@ core_sym_class (asymbol *sym)
 
 /* Get whatever source info we can get regarding address ADDR.  */
 
-static bfd_boolean
-get_src_info (bfd_vma addr, const char **filename, const char **name, int *line_num)
+static bool
+get_src_info (bfd_vma addr, const char **filename, const char **name,
+	      int *line_num)
 {
   const char *fname = 0, *func_name = 0;
   int l = 0;
@@ -469,7 +470,7 @@ get_src_info (bfd_vma addr, const char **filename, const char **name, int *line_
       *filename = fname;
       *name = func_name;
       *line_num = l;
-      return TRUE;
+      return true;
     }
   else
     {
@@ -477,7 +478,7 @@ get_src_info (bfd_vma addr, const char **filename, const char **name, int *line_
 			      (unsigned long) addr,
 			      fname ? fname : "<unknown>", l,
 			      func_name ? func_name : "<unknown>"));
-      return FALSE;
+      return false;
     }
 }
 
@@ -559,13 +560,15 @@ core_create_syms_from (const char * sym_table_file)
 
       sym_init (symtab.limit);
 
-      sscanf (address, "%" BFD_VMA_FMT "x", &(symtab.limit->addr) );
+      uint64_t addr;
+      sscanf (address, "%" SCNx64, &addr);
+      symtab.limit->addr = addr;
 
       symtab.limit->name = (char *) xmalloc (strlen (name) + 1);
       strcpy ((char *) symtab.limit->name, name);
       symtab.limit->mapped = 0;
-      symtab.limit->is_func = TRUE;
-      symtab.limit->is_bb_head = TRUE;
+      symtab.limit->is_func = true;
+      symtab.limit->is_bb_head = true;
       symtab.limit->is_static = (type == 't');
       min_vma = MIN (symtab.limit->addr, min_vma);
       max_vma = MAX (symtab.limit->addr, max_vma);
@@ -724,10 +727,10 @@ core_create_function_syms (void)
 
       symtab.limit->is_func = (!core_has_func_syms
 			       || (core_syms[i]->flags & BSF_FUNCTION) != 0);
-      symtab.limit->is_bb_head = TRUE;
+      symtab.limit->is_bb_head = true;
 
       if (cxxclass == 't')
-	symtab.limit->is_static = TRUE;
+	symtab.limit->is_static = true;
 
       /* Keep track of the minimum and maximum vma addresses used by all
 	 symbols.  When computing the max_vma, use the ending address of the
@@ -780,8 +783,8 @@ core_create_line_syms (void)
 
      Of course, this is rather slow and it would be better if
      BFD would provide an iterator for enumerating all line infos.  */
-  prev_name_len = PATH_MAX;
-  prev_filename_len = PATH_MAX;
+  prev_name_len = 1024;
+  prev_filename_len = 1024;
   prev_name = (char *) xmalloc (prev_name_len);
   prev_filename = (char *) xmalloc (prev_filename_len);
   ltab.len = 0;
