@@ -11,7 +11,7 @@ TEXT_START_ADDR=0x100
 #TEXT_LENGTH=0
 #DATA_ORIGIN=0
 #DATA_LENGTH=0
-EXTRA_EM_FILE=z80elf
+EXTRA_EM_FILE=z80
 
 #FUSE_NAME=fuse
 
